[llvm-commits] [llvm] r94060 - /llvm/trunk/include/llvm/PassAnalysisSupport.h

Chris Lattner sabre at nondot.org
Wed Jan 20 18:07:08 PST 2010


Author: lattner
Date: Wed Jan 20 20:07:07 2010
New Revision: 94060

URL: http://llvm.org/viewvc/llvm-project?rev=94060&view=rev
Log:
eliminate dynamic_cast from the pass manager.

Modified:
    llvm/trunk/include/llvm/PassAnalysisSupport.h

Modified: llvm/trunk/include/llvm/PassAnalysisSupport.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/PassAnalysisSupport.h?rev=94060&r1=94059&r2=94060&view=diff

==============================================================================
--- llvm/trunk/include/llvm/PassAnalysisSupport.h (original)
+++ llvm/trunk/include/llvm/PassAnalysisSupport.h Wed Jan 20 20:07:07 2010
@@ -19,15 +19,13 @@
 #ifndef LLVM_PASS_ANALYSIS_SUPPORT_H
 #define LLVM_PASS_ANALYSIS_SUPPORT_H
 
-#include <vector>
 #include "llvm/Pass.h"
 #include "llvm/ADT/SmallVector.h"
 #include "llvm/ADT/StringRef.h"
+#include <vector>
 
 namespace llvm {
 
-class StringRef;
-
 //===----------------------------------------------------------------------===//
 // AnalysisUsage - Represent the analysis usage information of a pass.  This
 // tracks analyses that the pass REQUIRES (must be available when the pass
@@ -192,8 +190,15 @@
 
   const PassInfo *PI = getClassPassInfo<AnalysisType>();
   if (PI == 0) return 0;
-  return dynamic_cast<AnalysisType*>
-    (Resolver->getAnalysisIfAvailable(PI, true));
+
+  Pass *ResultPass = Resolver->getAnalysisIfAvailable(PI, true);
+  if (ResultPass == 0) return 0;
+
+  // Because the AnalysisType may not be a subclass of pass (for
+  // AnalysisGroups), we use getAdjustedAnalysisPointer here to potentially
+  // adjust the return pointer (because the class may multiply inherit, once
+  // from pass, once from AnalysisType).
+  return (AnalysisType*)ResultPass->getAdjustedAnalysisPointer(PI);
 }
 
 /// getAnalysis<AnalysisType>() - This function is used by subclasses to get
@@ -202,8 +207,7 @@
 ///
 template<typename AnalysisType>
 AnalysisType &Pass::getAnalysis() const {
-  assert(Resolver &&"Pass has not been inserted into a PassManager object!");
-
+  assert(Resolver && "Pass has not been inserted into a PassManager object!");
   return getAnalysisID<AnalysisType>(getClassPassInfo<AnalysisType>());
 }
 
@@ -220,13 +224,10 @@
           "'required' by pass!");
 
   // Because the AnalysisType may not be a subclass of pass (for
-  // AnalysisGroups), we must use dynamic_cast here to potentially adjust the
-  // return pointer (because the class may multiply inherit, once from pass,
-  // once from AnalysisType).
-  //
-  AnalysisType *Result = dynamic_cast<AnalysisType*>(ResultPass);
-  assert(Result && "Pass does not implement interface required!");
-  return *Result;
+  // AnalysisGroups), we use getAdjustedAnalysisPointer here to potentially
+  // adjust the return pointer (because the class may multiply inherit, once
+  // from pass, once from AnalysisType).
+  return *(AnalysisType*)ResultPass->getAdjustedAnalysisPointer(PI);
 }
 
 /// getAnalysis<AnalysisType>() - This function is used by subclasses to get
@@ -248,16 +249,13 @@
   // should be a small number, we just do a linear search over a (dense)
   // vector.
   Pass *ResultPass = Resolver->findImplPass(this, PI, F);
-  assert (ResultPass &&  "Unable to find requested analysis info");
+  assert(ResultPass && "Unable to find requested analysis info");
   
   // Because the AnalysisType may not be a subclass of pass (for
-  // AnalysisGroups), we must use dynamic_cast here to potentially adjust the
-  // return pointer (because the class may multiply inherit, once from pass,
-  // once from AnalysisType).
-  //
-  AnalysisType *Result = dynamic_cast<AnalysisType*>(ResultPass);
-  assert(Result && "Pass does not implement interface required!");
-  return *Result;
+  // AnalysisGroups), we use getAdjustedAnalysisPointer here to potentially
+  // adjust the return pointer (because the class may multiply inherit, once
+  // from pass, once from AnalysisType).
+  return *(AnalysisType*)ResultPass->getAdjustedAnalysisPointer(PI);
 }
 
 } // End llvm namespace





More information about the llvm-commits mailing list